==> seedsui-react-5.7.84.tgz: package/lib/Photos/Status.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["visible", "type", "onReUpload"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';

// 状态:choose|uploading|fail|success
import { jsx as _jsx } from "react/jsx-runtime";
var Status = function Status(_ref, ref) {
  var visible = _ref.visible,
    type = _ref.type,
    onReUpload = _ref.onReUpload,
    props = _objectWithoutProperties(_ref, _excluded);
  if (!type) return null;
  if (visible === false) return null;
  return /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
    ref: ref,
    onClick: type === 'fail' ? onReUpload : undefined
  }, props), {}, {
    className: "photos-status ".concat(type || '').concat(props !== null && props !== void 0 && props.className ? ' ' + props.className : ''),
    children: /*#__PURE__*/_jsx("div", {
      className: "photos-status-icon",
      children: /*#__PURE__*/_jsx("svg", {
        viewBox: "25 25 50 50",
        className: "photos-status-icon-loading",
        children: /*#__PURE__*/_jsx("circle", {
          cx: "50",
          cy: "50",
          r: "20"
        })
      })
    })
  }));
};
export default /*#__PURE__*/forwardRef(Status);

==> seedsui-react-5.8.44.tgz: package/lib/Photos/Status.js <==
var _excluded = ["visible", "type", "onReUpload"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';

// 状态:choose|uploading|fail|success
var Status = function Status(_ref, ref) {
  var visible = _ref.visible,
    type = _ref.type,
    onReUpload = _ref.onReUpload,
    props = _objectWithoutProperties(_ref, _excluded);
  if (!type) return null;
  if (visible === false) return null;
  return /*#__PURE__*/React.createElement("div", _extends({
    ref: ref,
    onClick: type === 'fail' ? onReUpload : undefined
  }, props, {
    className: "photos-status ".concat(type || '').concat(props !== null && props !== void 0 && props.className ? ' ' + props.className : '')
  }), /*#__PURE__*/React.createElement("div", {
    className: "photos-status-icon"
  }, /*#__PURE__*/React.createElement("svg", {
    viewBox: "25 25 50 50",
    className: "photos-status-icon-loading"
  }, /*#__PURE__*/React.createElement("circle", {
    cx: "50",
    cy: "50",
    r: "20"
  }))));
};
export default /*#__PURE__*/forwardRef(Status);
